Plyvel — Plyvel 0.1 documentation

### Navigation

- index
- next |
- Plyvel 0.1 documentation »

# Plyvel

Plyvel is a fast and feature-rich Python interface to LevelDB.

Plyvel’s key features are:

- Rich feature set

  Plyvel wraps most of the LevelDB C++ API and adds some features of its own. In addition to basic features like getting, putting and deleting data, Plyvel allows you to use write batches, database snapshots, very flexible iterators, prefixed databases, bloom filters, custom cache sizes, custom comparators, and other goodness LevelDB has to offer.

- Friendly Pythonic API

  Plyvel has a friendly and well-designed API that uses Python idioms like iterators and context managers (`with` blocks), without sacrificing the power or performance of the underlying LevelDB C++ API.

- High performance

  Plyvel executes all performance-critical code at C speed (using Cython), which means Plyvel is a good fit for high performance applications.

- Extensive documentation

  Plyvel comes with extensive documentation, including a user guide and API reference material.

- Python 2 and Python 3 compatibility

  Plyvel works with both Python 2 and Python 3, without any API differences.

## Documentation overview

The documentation consists of three main parts:

- Installation guide

  The installation guide describes how to install Plyvel.

- User guide

  The user guide shows how to use Plyvel and describes most features.

- API reference

  The API reference contains all details about the Plyvel API.

See the full table of contents below for additional documentation.

## External links

- Online documentation (Read the docs)
- Project page with source code and issue tracker (Github)

## Table of contents

- Installation guide
  - Build and install Plyvel
  - Verify that it works
- User guide
  - Getting started
  - Basic operations
  - Important note about byte strings
  - Write batches
  - Snapshots
  - Iterators
    - Iterating over a key range
    - Limiting the returned data
    - Iterating in reverse order
    - Iterating over snapshots
    - Advanced iterator usage
  - Prefixed databases
  - Custom comparators
- API reference
  - Database
    - Prefixed database
    - Database maintenance
  - Write batch
  - Snapshot
  - Iterator
  - Errors
- Contributing and developing
  - Reporting issues
  - Obtaining the source code
  - Compiling the code
  - Running the tests
  - Generating the documentation
- License

- Index
- Module Index
- Search Page

### Navigation

- index
- next |
- Plyvel 0.1 documentation »